--[[
		    ----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----


                                                 #            ####     #       #     ####  
                                                 #          ##    ##   ##      #   ##    ##
                                                 #         ##      ##  # #     #  ##
                                                 #         #        #  #  #    #  #
                                                 #         #        #  #   #   #  #
                                                 #         #        #  #    #  #  #     ###
                                                 #         ##      ##  #     # #  ##      #
                                                 #          ##    ##   #      ##   ##    ##
                                                 ########     ####     #       #     ####  


                                    ####    #########  #######      ####    #       #     ####    ########
                                  ##    ##      #      #     ##    ##  ##   ##      #   ##    ##  #
                                  #             #      #       #  #      #  # #     #  ##         #
                                  ##            #      #     ##   #      #  #  #    #  #          #
                                   ######       #      #######    ########  #   #   #  #          ########
                                        ##      #      #   #      #      #  #    #  #  #     ###  #
                                          #     #      #    #     #      #  #     # #  ##      #  #
                                  ##    ##      #      #     #    #      #  #      ##   ##    ##  #
                                    ####        #      #      #   #      #  #       #     ####    ########


                                                     #########  #######    #  #######
                                                         #      #     ##   #  #     ##
                                                         #      #       #  #  #       #
                                                         #      #     ##   #  #     ##
                                                         #      #######    #  #######
                                                         #      #   #      #  #
                                                         #      #    #     #  #
                                                         #      #     #    #  #
                                                         #      #      #   #  #


                                                       --==  BATTLE FOR AZEROTH  ==--


                    ----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----


                                                    ----o----(||)----oo----(||)----o----

                                                          v1.07 25th February 2019
                                                    Copyright (C) Taraezor / Chris Birch

                                                    ----o----(||)----oo----(||)----o----


]]

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Localisations and Local Data
--		============================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local addonName, L = ...
local addonTitle = addonName

local format = string.format
local pairs = pairs
local tonumber = tonumber
local tostring = tostring

local CreateFrame = CreateFrame
local GetAchievementCriteriaInfo = GetAchievementCriteriaInfo
local GetAchievementInfo = GetAchievementInfo
local GetCVar = GetCVar
local GetTime = GetTime
local IsQuestFlaggedCompleted = IsQuestFlaggedCompleted
local WorldMapTooltip = WorldMapTooltip

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Local Functions
--		===============
--
--------------------------------------------------------------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Build / Version Setup
--		=====================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local buildVersion = GetBuildInfo()
local _, _, buildVersion = string.find( buildVersion, "(%d+\.%d+)" )
buildVersion = tonumber( buildVersion )

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Colour Printing - Brown Theme
--		===============
--
--------------------------------------------------------------------------------------------------------------------------------------------

local pc_colour_Prefix		= "\124cFFD2691E"	-- X11Chocolate
local pc_colour_Highlight	= "\124cFFF4A460"	-- X11SandyBrown
local pc_colour_PlainText	= "\124cFFDEB887"	-- X11BurlyWood

local function printPC( message )
	if message then
		DEFAULT_CHAT_FRAME:AddMessage( pc_colour_Prefix.. addonTitle.. ": ".. pc_colour_PlainText.. message.. "\124r" )
	end
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Expansion Check
--		===============
--
--------------------------------------------------------------------------------------------------------------------------------------------

if ( buildVersion < 8.0 ) then
	printPC( pc_colour_Highlight.. L[ "Requires Battle for Azeroth (8.0.1) or higher" ] )
	return
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Pin Textures
--		============
--
--		"size" is to normalise textures amongst themselves with "1" to be the average size
--		"scaling" is to adjust the size of all used textures so that they appear reasonable on a certain map. Allowance has been made for
--		how cluttered a map might become if I were to add many icons
--		"coords" is to allow a texture within a group of textures to be used
--
--------------------------------------------------------------------------------------------------------------------------------------------

local texturesAssigned = {
		special = {
			timetravel = "5",
			},
		lunar = {
			eldersA = "1",
			eldersH = "2",
			eldersD = "3",
			elders = "4",
			},
		love = {
			fool = "6",
			stinksA = "8",
			stinksH = "8",
			nationA = "7",
			nationH = "7",
			},
		noble = {
			flingA = "10",
			flingH = "9",
			desert = "11",
			hard = "12",
			},
		midsummer = {
			warden = "",	-- "Interface\\HelpFrame\\HotIssueIcon" is perfect for every zone
			bonfireA = "",	-- ?
			bonfireH = "",	-- ?
			},
		hallow = {
			tricktreat = "",	-- game uses a different one for every zone
			},
		pilgrim = {
			peril = "",	-- ?
			turkinator = "",	-- good locations of turkeys
			},
		winter = {
			bbking = "",	-- ?
			acaroling = "",	-- ?
			scrooge = "",	-- ?
			bros = "",	-- ?
			falalala = "",	-- ?
			metzen = "",	-- ?
			},
		}

local textures = {
		["1"] = "Interface\\AddOns\\LongStrangeTrip\\AncestorCoinA", ["2"] = "Interface\\AddOns\\LongStrangeTrip\\AncestorCoinH",
		["3"] = "Interface\\AddOns\\LongStrangeTrip\\AncestorCoinD", ["4"] = "Interface\\AddOns\\LongStrangeTrip\\AncestorCoin",
		["5"] = "Interface\\CharacterFrame\\Disconnect-Icon", ["6"] = "Interface\\AddOns\\LongStrangeTrip\\Love",
		["7"] = "Interface\\AddOns\\LongStrangeTrip\\LoveG", ["8"] = "Interface\\AddOns\\LongStrangeTrip\\LoveYB",
		["9"] = "Interface\\AddOns\\LongStrangeTrip\\NobleH", ["10"] = "Interface\\AddOns\\LongStrangeTrip\\NobleA",
		["11"] = "Interface\\AddOns\\LongStrangeTrip\\NobleG", ["12"] = "Interface\\AddOns\\LongStrangeTrip\\NobleP",

		coords = { ["1"] = { 0, 1, 0, 1}, ["2"] = { 0, 1, 0, 1}, ["3"] = { 0, 1, 0, 1}, ["4"] = { 0, 1, 0, 1}, ["5"] = { 0, 1, 0, 1}, 
					["6"] = { 0, 1, 0, 1}, ["7"] = { 0, 1, 0, 1}, ["8"] = { 0, 1, 0, 1}, ["9"] = { 0, 1, 0, 1}, ["10"] = { 0, 1, 0, 1}, 
					["11"] = { 0, 1, 0, 1}, ["12"] = { 0, 1, 0, 1},
		},
		size = { ["1"] = 0.7, ["2"] = 0.7, ["3"] = 0.7, ["4"] = 0.7, ["5"] = 1.1, ["6"] = 0.75, ["7"] = 0.75, ["8"] = 0.75, ["9"] = 0.75, 
				["10"] = 0.75, ["11"] = 0.75, ["12"] = 0.75,

		},
	}

local scaling = {
		["0"] = { ["12"] = 3, ["13"] = 3, ["113"] = 1, ["140"] = 1, ["947"] = 2, ["57"] = 1.3, },
		["1"] = { ["12"] = 3, ["13"] = 3, ["113"] = 1.4, ["140"] = 1.5, ["947"] = 2.25, },
		}
setmetatable( scaling[ "0" ], { __index = function( scaling, key ) return 0.8 end } )
setmetatable( scaling[ "1" ], { __index = function( scaling, key ) return 1.4 end } )

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Locations
--		=========
--
--		"tips" is organised in a manner convenient for manual data collection and checking. When the AddOn launches I reorganise the data
--		into a structure more suited to the AddOn
--
--------------------------------------------------------------------------------------------------------------------------------------------

local tips = {

	lunar = {
		eldersA = {
			["Elder Bladeswift"] = { 
				quest = { 8718 },
				["1"] = {
					["location"] = "Cenarion Enclave",
					["89"] = { ["x"] = 39.21, ["y"] = 31.86, },
					["57"] = { ["x"] = 28.11, ["y"] = 43.67, },
					["12"] = { ["x"] = 39.36, ["y"] = 8.85, },
					["947"] = { ["x"] = 13.59, ["y"] = 34.51, },
					},
				},
			["Elder Bronzebeard"] = { 
				quest = { 8866 },
				["1"] = {
					["location"] = "The Mystic Ward", ["tip"] = "Horde swooping low may get noticed by a ground patrol.\nRetreat, study, "..
									"try again",
					["87"] = { ["x"] = 29.20, ["y"] = 17.05, },
					},
				["2"] = {
					["location"] = "Alcove above statue", 
					["tip"] = "Horde fly in and go straight and up and stop\nhere in the alcove. If there are no Gryphon\nRiders, drop "..
								"straight into the central canal/\ndrain. Go left to the end",
					["87"] = { ["x"] = 24.59, ["y"] = 74.41, },
					},
				["3"] = {
					["location"] = "Canal/Drain", 
					["tip"] = "Horde wait here. Observe the Gryphon Riders patrol pattern.\nWhen safe(st) swoop up and in, turn and "..
								"exit via the canal",
					["87"] = { ["x"] = 23.95, ["y"] = 34.96, },
					},
				["4"] = {
					["location"] = "Ironforge (Inside)", ["tip"] = "The Mystic Ward. Enter here.\nHorde: zoom in the map for a "..
									"detailed guide. At level\n80 you will be one-shotted at the Gates of Ironforge.\nRez inside the "..
									"Gates in a side alcove as you'll be out\nof Guard vision. Nearest repairs at Thorium Point",
					["27"] = { ["x"] = 62.92, ["y"] = 21.98, },
					["56"] = { ["x"] = 13.42, ["y"] = 91.11, },
					["13"] = { ["x"] = 46.92, ["y"] = 58.33, },
					["947"] = { ["x"] = 86.61, ["y"] = 56.13, },
					},
				},
			["Elder Hammershout"] = { 
				quest = { 8646 },
				["1"] = {
					["location"] = "Storwind", ["tip"] = "Outside the main gate. Horde can safely\nswoop in from the north",
					["84"] = { ["x"] = 79.83, ["y"] = 95.57, },
					["37"] = { ["x"] = 34.56, ["y"] = 50.26, },
					["13"] = { ["x"] = 43.78, ["y"] = 74.69, },
					["947"] = { ["x"] = 84.92, ["y"] = 64.89, },
					},
				},
			},
		eldersD = {
			["Elder Chogan'gada"] = { 
				quest = { 13067 },
				["1"] = {
					["location"] = "Utgarde Pinnacle",
					["tip"] = "Enter the instance here\nThe entrance is close to the ground. Start\nNORTH of the map marker and fly "..
								"towards it",
					["117"] = { ["x"] = 57.27, ["y"] = 46.70, },
					["113"] = { ["x"] = 79.30, ["y"] = 79.09, },
					["947"] = { ["x"] = 57.22, ["y"] = 22.24, },
					},
				["2"] = {
					["tip"] = "Defeat Skadi. Go through the raised\nportcullis and down the stairs",
					["137"] = { ["x"] = 68.62, ["y"] = 42.52, },
					},
				["3"] = {
					["location"] = "Stairs after Skadi", 
					["tip"] = "When you reach the bottom, do a\n\"u-turn\" to a room under the stairs",
					["136"] = { ["x"] = 48.47, ["y"] = 22.76, },
					},
				},
			["Elder Farwhisper"] = { 
				quest = { 8727 },
				["1"] = {
					["location"] = "Stratholme", ["tip"] = "Enter the instance here",
					["23"] = { ["x"] = 26.44, ["y"] = 11.62, },
					["13"] = { ["x"] = 52.83, ["y"] = 28.67, },
					["947"] = { ["x"] = 89.77, ["y"] = 40.27, },
					},
				["2"] = {
					["location"] = "Festival Lane", 
					["tip"] = "At the main (first) street junction turn right.\nRaise two portcullis and keep going. Can't be missed",
					["317"] = { ["x"] = 78.35, ["y"] = 21.82, },
					},
				},
			["Elder Igasho"] = { 
				quest = { 13021 },
				["1"] = {
					["location"] = "The Nexus", ["tip"] = "Enter the instance here. Go straight\nforward and descend",
					["114"] = { ["x"] = 27.76, ["y"] = 28.12, },
					["113"] = { ["x"] = 12.66, ["y"] = 57.26, },
					["947"] = { ["x"] = 40.73, ["y"] = 17.08, },
					},
				["2"] = {
					["location"] = "The Singing Grove", 
					["tip"] = "Just follow the path",
					["129"] = { ["x"] = 55.06, ["y"] = 64.56, },
					},
				},
			["Elder Jarten"] = { 
				quest = { 13017 },
				["1"] = {
					["location"] = "Utgarde Keep",
					["tip"] = "Enter the instance here\nThe entrance is at ground level, up some wooden stairs.\nStart SOUTH of the map "..
								"marker and fly "..
								"towards it",
					["117"] = { ["x"] = 58.19, ["y"] = 50.95, },
					["113"] = { ["x"] = 79.62, ["y"] = 80.54, },
					["947"] = { ["x"] = 57.29, ["y"] = 22.58, },
					},
				["2"] = {
					["location"] = "Prince Keleseth", 
					["tip"] = "Follow the linear path",
					["133"] = { ["x"] = 47.33, ["y"] = 69.24, },
					},
				},
			["Elder Kilias"] = { 
				quest = { 13023 },
				["1"] = {
					["location"] = "Drak'Tharon Keep", ["tip"] = "Enter the instance here",
					["121"] = { ["x"] = 28.98, ["y"] = 83.66, },
					["116"] = { ["x"] = 17.85, ["y"] = 18.09, },
					["113"] = { ["x"] = 63.46, ["y"] = 48.25, },
					["947"] = { ["x"] = 53.30, ["y"] = 14.95, },
					},
				["2"] = {
					["location"] = "Drak'Tharon Keep", ["tip"] = "Enter the instance here\n(better from the Zul'Drak side as less walking)",
					["116"] = { ["x"] = 17.79, ["y"] = 27.69, },
					},
				["3"] = {
					["location"] = "Drak'Tharon Keep", ["tip"] = "No shortcuts. You have to follow\nthe linear path to here",
					["160"] = { ["x"] = 68.74, ["y"] = 78.74, },
					},
				},
			["Elder Morndeep"] = {
				quest = { 8619 },
				["1"] = {
					["location"] = "Blackrock Depths - Ring of Law", 
					["tip"] = "Multiple ways to get there. Mole Machine to The Domicile and then jump down is quick",
					["33"] = { ["x"] = 39.77, ["y"] = 40.23, },
					["35"] = { ["x"] = 38.77, ["y"] = 18.11, },
					["242"] = { ["x"] = 50.23, ["y"] = 62.66, },
					},
				},
			["Elder Morndeep & Elder Stonefort"] = {
				quest = { 8619, 8644 },
				["1"] = {
					["location"] = "Blackrock Mountain dungeons",
					["tip"] = "Enter here. Constantly check the maps for a detailed guide",
					["32"] = { ["x"] = 35.00, ["y"] = 84.94, },
					["13"] = { ["x"] = 47.31, ["y"] = 68.29, },
					["947"] = { ["x"] = 86.81, ["y"] = 61.46, },
					},
				["2"] = {
					["location"] = "Blackrock Mountain dungeons",
					["tip"] = "Enter here. Constantly check the maps for a detailed guide",
					["36"] = { ["x"] = 21.12, ["y"] = 38.62, },
					["13"] = { ["x"] = 47.38, ["y"] = 69.88, },
					["947"] = { ["x"] = 86.85, ["y"] = 62.32, },
					},
				},
			["Elder Nurgen"] = {
				quest = { 13022 },
				["1"] = {
					["location"] = "Azjol-Nerub", 
					["tip"] = "Fly down exactly at these coordinates. Look around\nand you'll see the meeting stone and portal",
					["115"] = { ["x"] = 26.29, ["y"] = 49.25, },
					["113"] = { ["x"] = 39.80, ["y"] = 57.97, },
					["947"] = { ["x"] = 47.45, ["y"] = 17.25, },
					},
				["2"] = {
					["location"] = "Hadronox's Lair", 
					["tip"] = "#1: Enter the Lair and drop down",
					["159"] = { ["x"] = 77.74, ["y"] = 44.42, },
					},
				["3"] = {
					["location"] = "Hadronox's Lair", 
					["tip"] = "#2 Take the webbed path over here",
					["159"] = { ["x"] = 69.38, ["y"] = 26.87, },
					},
				["4"] = {
					["location"] = "Hadronox's Lair", 
					["tip"] = "There is a hole in the web about here. Drop down.\nNow fall through the nearby hole in the floor",
					["158"] = { ["x"] = 48.22, ["y"] = 69.31, },
					},
				["5"] = {
					["location"] = "The Brood Pit", 
					["tip"] = "You fall safely into a pond. Look around, the Elder is nearby",
					["157"] = { ["x"] = 21.61, ["y"] = 43.40, },
					},
				},
			["Elder Ohanzee"] = {
				quest = { 13065 },
				["1"] = {
					["location"] = "Gundrak",
					["tip"] = "Enter the instance here",
					["121"] = { ["x"] = 76.32, ["y"] = 21.24, },
					["120"] = { ["x"] = 87.91, ["y"] = 68.25, },
					["113"] = { ["x"] = 76.77, ["y"] = 30.69, },
					["947"] = { ["x"] = 56.59, ["y"] = 10.80, },
					},
				["2"] = {
					["location"] = "Gundrak",
					["tip"] = "Go this way",
					["154"] = { ["x"] = 58.61, ["y"] = 56.51, },
					},
				["3"] = {
					["location"] = "Gundrak",
					["tip"] = "Behind the Drakarri Colossus",
					["154"] = { ["x"] = 45.43, ["y"] = 61.14, },
					},
				},
			["Elder Splitrock"] = {
				quest = { 8635 },
				["1"] = {
					["location"] = "Maraudon (deep within)",
					["tip"] = "Run through the entrance and down the winding path. At the junction take the\nmiddle path. Do not take "..
								"either of the \"crystal\" paths. At the bottom of\nthe path, step into the portal. Jump down the "..
								"waterfall. Go straight ahead.\nDue south, bearing slighlty east on the map. Follow the path out of the "..
								"hydra\ncavern. At the first junction take the ramp to the left. Cross the bridge and\ngo left. You will "..
								"come to a ledge with a path to the right. Jump off the ledge\nonto the bridge below (ouch) and enter "..
								"the cave. You'll see Elder Splitrock.\n\n".. 
								"Exit: Back to that bridge. Turn left. Eventually you return to a previous\njunction. Retrace your steps "..
								"back to the hydra cavern. Stay left to exit the\nchamber. Follow the path, past the waterfall, past "..
								"Celebras. At the junction\nwith the green ooze waterfall, go right. Later take the stairs down (the "..
								"only\nway), and then bear left in the Grotto. Bear left again and take a ramp left\nand up. Cross the "..
								"little bridge and follow the pink/purple crystals out. Bear\nleft (south), emerging at Zaetar's Choice. "..
								"The way out is to the right",
					["281"] = { ["x"] = 51.24, ["y"] = 93.39, },
					["66"] = { ["x"] = 29.30, ["y"] = 62.50, },
					["12"] = { ["x"] = 38.45, ["y"] = 55.97, },
					["947"] = { ["x"] = 13.16, ["y"] = 56.80, },
					},
				},
			["Elder Starsong"] = {
				quest = { 8713 },
				["1"] = {
					["location"] = "Sunken Temple",
					["tip"] = "First wing on the left from the instance entrance",
					["220"] = { ["x"] = 62.70, ["y"] = 34.10, },
					["51"] = { ["x"] = 69.47, ["y"] = 54.57, },
					["13"] = { ["x"] = 53.99, ["y"] = 79.65, },
					["947"] = { ["x"] = 90.39, ["y"] = 67.54, },
					},
				},
			["Elder Stonefort"] = {
				quest = { 8644 },
				["1"] = {
					["location"] = "Wrong way!",
					["34"] = { ["x"] = 61.22, ["y"] = 55.00, },
					},
				["2"] = {
					["location"] = "Here!",
					["251"] = { ["x"] = 61.55, ["y"] = 39.76, },
					["252"] = { ["x"] = 61.55, ["y"] = 39.76, },
					},
				["3"] = {
					["tip"] = "Go straight ahead and down",
					["252"] = { ["x"] = 37.63, ["y"] = 42.24, },
					},
				["4"] = {
					["tip"] = "You can see Elder Stonefort\nstraight ahead in the distance",
					["253"] = { ["x"] = 46.41, ["y"] = 43.57, },
					},
				["5"] = {
					["location"] = "Lower Blackrock Spire", ["tip"] = "Fly up to here. Go forwards and up",
					["33"] = { ["x"] = 63.32, ["y"] = 44.30, },
					},
				["6"] = {
					["tip"] = "A large room with wide stairs\nleading upwards and downwards. Go\nDOWN and take the portal on the RIGHT",
					["33"] = { ["x"] = 61.22, ["y"] = 55.00, },
					},
				},
			["Elder Wildmane"] = {
				quest = { 8676 },
				["1"] = {
					["location"] = "Zul'Farrak (instance)", ["tip"] = "East of Gahz'rilla's spawn location. Difficult to stealth completely",
					["219"] = { ["x"] = 34.43, ["y"] = 39.25, },
					["71"] = { ["x"] = 39.22, ["y"] = 21.34, },
					["78"] = { ["x"] = 92.55, ["y"] = 33.66, },
					["64"] = { ["x"] = 55.86, ["y"] = 96.49, },
					["12"] = { ["x"] = 54.23, ["y"] = 77.88, },
					["947"] = { ["x"] = 20.63, ["y"] = 67.16, },
					},
				},
			["Elder Yurauk"] = {
				quest = { 13066 },
				["1"] = {
					["location"] = "Halls of Stone", ["tip"] = "Enter the instance here",
					["120"] = { ["x"] = 39.67, ["y"] = 26.90, },
					["113"] = { ["x"] = 57.44, ["y"] = 14.12, },
					["947"] = { ["x"] = 51.81, ["y"] = 6.88, },
					},
				["2"] = {
					["location"] = "Krystallus", ["tip"] = "Just follow the map. Before you get to Krystallus",
					["140"] = { ["x"] = 29.22, ["y"] = 61.71, },
					},
				},
			},
		eldersH = {
			["Elder Darkcore"] = {
				quest = { 8648 },
				["1"] = {
					["location"] = "Ruins of Lordaeron",
					["tip"] = "ABOVE Undercity. Alliance may safely descend",
					["90"] = { ["x"] = 66.63, ["y"] = 38.20, },
					["22"] = { ["x"] = 4.25, ["y"] = 60.47, },
					["21"] = { ["x"] = 76.58, ["y"] = 1.20, },
					["18"] = { ["x"] = 61.95, ["y"] = 73.17, },
					["13"] = { ["x"] = 44.03, ["y"] = 35.15, },
					["947"] = { ["x"] = 85.06, ["y"] = 43.73, },
					},
				},
			["Elder Darkhorn"] = {
				quest = { 8677 },
				["1"] = {
					["location"] = "Orgimmar (central mesa)",
					["tip"] = "If dropping down as Alliance, aim for the SOUTHERN of the two light\nbeacons. If hit, run east for the "..
								"easiest corpse rez as the run is BRUTAL.\nIf badly cut-up then repairs can be had later from Lizzarik "..
								"in Ratchet",
					["85"] = { ["x"] = 52.25, ["y"] = 60.00, },
					["10"] = { ["x"] = 80.36, ["y"] = 0.51, },
					["76"] = { ["x"] = 18.90, ["y"] = 97.64, },
					["1"] = { ["x"] = 46.39, ["y"] = 0.49, },
					["12"] = { ["x"] = 58.37, ["y"] = 42.87, },
					["947"] = { ["x"] = 22.59, ["y"] = 50.60, },
					},
				},
			["Elder Ezra Wheathoof"] = {
				quest = { 8678 },
				["1"] = {
					["location"] = "Elder Rise (Thunder Bluff)", ["tip"] = "On the north-west side. Alliance will not be troubled",
					["88"] = { ["x"] = 72.99, ["y"] = 23.37, },
					["7"] = { ["x"] = 44.94, ["y"] = 23.23, },
					["199"] = { ["x"] = 21.60, ["y"] = 24.62, },
					["10"] = { ["x"] = 7.78, ["y"] = 73.68, },
					["66"] = { ["x"] = 99.61, ["y"] = 48.86, },
					["12"] = { ["x"] = 47.04, ["y"] = 54.30, },
					["947"] = { ["x"] = 17.23, ["y"] = 56.01, },
					},
				},
			},
		elders = {
			["Elder Arp"] = {
				quest = { 13033 },
				["1"] = {
					["location"] = "D.E.H.T.A. Encampment",
					["114"] = { ["x"] = 57.40, ["y"] = 43.72, },
					["113"] = { ["x"] = 22.28, ["y"] = 62.33, },
					["947"] = { ["x"] = 43.11, ["y"] = 18.28, },
					},
				},
			["Elder Beldak"] = {
				quest = { 13013 },
				["1"] = {
					["location"] = "Westfall Brigade Encampment", ["tip"] = "To the east of the camp. Safe for Horde",
					["116"] = { ["x"] = 60.57, ["y"] = 27.68, },
					["121"] = { ["x"] = 73.90, ["y"] = 93.74, },
					["113"] = { ["x"] = 76.09, ["y"] = 51.08, },
					["947"] = { ["x"] = 56.42, ["y"] = 15.62, },
					},
				},
			["Elder Bellowrage"] = {
				quest = { 8647 },
				["1"] = {
					["location"] = "The Dark Portal", ["tip"] = "BEFORE the invasion. Speak to Zidormi if you cannot see the NPC",
					["17"] = { ["x"] = 54.28, ["y"] = 49.49, },
					["224"] = { ["x"] = 94.00, ["y"] = 18.93, },
					["13"] = { ["x"] = 52.41, ["y"] = 84.60, },
					["947"] = { ["x"] = 89.54, ["y"] = 70.19, },
					},
				},
			["Elder Bladeleaf"] = {
				quest = { 8715 },
				["1"] = {
					["location"] = "Dolanaar", 
					["tip"] = "South-east edge of town.\nHorde must deal with a Teldrassil Sentinel mere yards away.\nThe Spirit Healer "..
								"is at (55.86,55.26), to the south-west so\nthe run is not bad. Drop straight down etc. The only way",
					["57"] = { ["x"] = 56.85, ["y"] = 53.11, },
					["12"] = { ["x"] = 43.94, ["y"] = 10.36, },
					["947"] = { ["x"] = 15.76, ["y"] = 35.22, },
					},
				},
			["Elder Bladesing"] = {
				quest = { 8719 },
				["1"] = {
					["location"] = "Cenarion Hold",
					["81"] = { ["x"] = 53.02, ["y"] = 35.47, },
					["69"] = { ["x"] = 66.33, ["y"] = 96.39, },
					["12"] = { ["x"] = 44.12, ["y"] = 78.03, },
					["947"] = { ["x"] = 15.84, ["y"] = 67.23, },
					},
				},
			["Elder Bloodhoof"] = {
				quest = { 8673 },
				["1"] = {
					["location"] = "Bloodhoof Village", ["tip"] = "At the bridge north of and outside of the village",
					["7"] = { ["x"] = 48.50, ["y"] = 53.24, },
					["199"] = { ["x"] = 24.22, ["y"] = 46.69, },
					["12"] = { ["x"] = 47.57, ["y"] = 58.75, },
					["947"] = { ["x"] = 17.48, ["y"] = 58.11, },
					},
				},
			["Elder Bluewolf"] = {
				quest = { 13026 },
				["1"] = {
					["location"] = "Wintergrasp Fortress (Inside)", 
					["tip"] = "To enter, click on the portal here.\nYour faction must hold Wintergrasp",
					["123"] = { ["x"] = 50.45, ["y"] = 16.42, },
					["118"] = { ["x"] = 41.71, ["y"] = 96.53, },
					["119"] = { ["x"] = 94.14, ["y"] = 65.30, },
					["115"] = { ["x"] = 14.24, ["y"] = 4.92, },
					["113"] = { ["x"] = 35.99, ["y"] = 43.96, },
					["947"] = { ["x"] = 46.50, ["y"] = 13.94, },
					},
				},
			["Elder Brightspear"] = {
				quest = { 8726 },
				["1"] = {
					["location"] = "The Ruins of Kel'Theril", 
					["tip"] = "She's standing on the south east side of the lake.\nA Highborne Night Elf wearing a lovely pink robe",
					["83"] = { ["x"] = 53.23, ["y"] = 56.75, },
					["77"] = { ["x"] = 100.00, ["y"] = 19.06, },	-- I had to shift slighly to the left to make this happen
					["12"] = { ["x"] = 57.97, ["y"] = 23.81, },
					["947"] = { ["x"] = 22.39, ["y"] = 41.58, },
					},
				},
			["Elder Darkfeather"] = {
				quest = { 29736 },
				["1"] = {
					["location"] = "Thundermar Ruins", ["tip"] = "Alliance need to watch a level 90\nmob patroling rather close by",
					["241"] = { ["x"] = 51.88, ["y"] = 33.07, },
					["13"] = { ["x"] = 57.30, ["y"] = 53.39, },
					["947"] = { ["x"] = 92.16, ["y"] = 53.49, },
					},
				},
			["Elder Dawnstrider"] = {
				quest = { 8683 },
				["1"] = {
					["location"] = "Flame Crest",
					["36"] = { ["x"] = 52.38, ["y"] = 23.93, },
					["15"] = { ["x"] = 6.95, ["y"] = 79.86, },
					["32"] = { ["x"] = 80.35, ["y"] = 93.31, },
					["13"] = { ["x"] = 49.80, ["y"] = 68.75, },
					["947"] = { ["x"] = 88.14, ["y"] = 61.71, },
					},
				},
			["Elder Deepforge"] = {
				quest = { 29734 },
				["1"] = {
					["location"] = "Stonehearth (Deepholm)",
					["tip"] = "Take the Deepholm portal in your capital city.\nOn arrival, fly south-west to Stonehearth",
					["207"] = { ["x"] = 27.71, ["y"] = 69.18, },
					["948"] = { ["x"] = 49.4, ["y"] = 29.3, },
					["947"] = { ["x"] = 45, ["y"] = 48.8, },
					},
				},
			["Elder Dreamseer"] = {
				quest = { 8684 },
				["1"] = {
					["location"] = "Gadgetzan", ["tip"] = "Eastern side of the arena",
					["71"] = { ["x"] = 51.40, ["y"] = 28.81, },
					["12"] = { ["x"] = 56.62, ["y"] = 79.34, },
					["947"] = { ["x"] = 21.76, ["y"] = 67.86, },
					},
				},
			["Elder Evershade"] = {
				quest = { 29740 },
				["1"] = {
					["location"] = "Nordrassil", ["tip"] = "Adjacent to the Alliance Stormwind portal",
					["198"] = { ["x"] = 62.54, ["y"] = 22.82, },
					["83"] = { ["x"] = 42.16, ["y"] = 79.12, },
					["77"] = { ["x"] = 88.78, ["y"] = 41.76, },
					["12"] = { ["x"] = 56.12, ["y"] = 27.55, },
					["947"] = { ["x"] = 21.52, ["y"] = 43.35, },
					},
				},
			["Elder Fargal"] = {
				quest = { 13015 },
				["1"] = {
					["location"] = "Frosthold", ["tip"] = "On a ridge to the north. Horde approach from the north",
					["120"] = { ["x"] = 28.89, ["y"] = 73.71, },
					["118"] = { ["x"] = 90.21, ["y"] = 65.15, },
					["113"] = { ["x"] = 53.12, ["y"] = 32.88, },
					["947"] = { ["x"] = 50.74, ["y"] = 11.32, },
					},
				},
			["Elder Firebeard"] = {
				quest = { 29737 },
				["1"] = {
					["location"] = "Dunwald Town Square",
					["tip"] = "Lowbies take note that if you plan to drop in and soar out, there\nare plenty of level 84 Highland Black "..
								"Drakes circling above",
					["241"] = { ["x"] = 50.91, ["y"] = 70.45, },
					["13"] = { ["x"] = 57.17, ["y"] = 58.23, },
					["947"] = { ["x"] = 92.09, ["y"] = 56.08, },
					},
				},
			["Elder Goldwell"] = {
				quest = { 8653 },
				["1"] = {
					["location"] = "Kharanos", ["tip"] = "Horde beware of a nearby Dun Morogh Mountaineer",
					["27"] = { ["x"] = 53.90, ["y"] = 49.91, },
					["469"] = { ["x"] = 92.37, ["y"] = 68.42, },
					["13"] = { ["x"] = 45.84, ["y"] = 61.69, },
					["947"] = { ["x"] = 86.03, ["y"] = 57.93, },
					},
				},
			["Elder Graveborn"] = {
				quest = { 8652 },
				["1"] = {
					["location"] = "Brill", 
					["tip"] = "At the southern end. Alliance should drop in quickly.\nYou'll take a shot from a guard",
					["18"] = { ["x"] = 61.86, ["y"] = 53.91, },
					["22"] = { ["x"] = 4.16, ["y"] = 40.23, },
					["13"] = { ["x"] = 44.02, ["y"] = 33.01, },
					["947"] = { ["x"] = 85.05, ["y"] = 42.59, },
					},
				},
			["Elder Graymane"] = {
				quest = { 13028 },
				["1"] = {
					["location"] = "K3", 
					["tip"] = "Outside the compound, to the north",
					["120"] = { ["x"] = 41.16, ["y"] = 84.73, },
					["121"] = { ["x"] = 9.73, ["y"] = 44.71, },
					["127"] = { ["x"] = 92.89, ["y"] = 17.74, },
					["113"] = { ["x"] = 58.04, ["y"] = 37.29, },
					["947"] = { ["x"] = 51.96, ["y"] = 12.36, },
					},
				},
			["Elder Grimtotem"] = {
				quest = { 8679 },
				["1"] = {
					["location"] = "Lariss Pavillion",
					["69"] = { ["x"] = 76.71, ["y"] = 37.89, },
					["199"] = { ["x"] = 16.81, ["y"] = 87.55, },
					["12"] = { ["x"] = 46.08, ["y"] = 66.98, },
					["947"] = { ["x"] = 16.77, ["y"] = 62.01, },
					},
				},
			["Elder High Mountain"] = {
				quest = { 8686 },
				["1"] = {
					["location"] = "Vendetta Point", ["tip"] = "Adjacent to the Wind Rider Master",
					["199"] = { ["x"] = 41.60, ["y"] = 47.45, },
					["70"] = { ["x"] = 14.33, ["y"] = 3.07, },
					["7"] = { ["x"] = 72.13, ["y"] = 54.27, },
					["12"] = { ["x"] = 51.07, ["y"] = 58.90, },
					["947"] = { ["x"] = 19.13, ["y"] = 58.18, },
					},
				},
			["Elder Highpeak"] = {
				quest = { 8643 },
				["1"] = {
					["location"] = "The Creeping Ruin", ["tip"] = "Just to the north",
					["26"] = { ["x"] = 50.00, ["y"] = 48.05, },
					["13"] = { ["x"] = 53.19, ["y"] = 40.31, },
					["947"] = { ["x"] = 89.96, ["y"] = 46.49, },
					},
				},
			["Elder Ironband"] = {
				quest = { 8651 },
				["1"] = {
					["location"] = "Blackchar Cave",
					["32"] = { ["x"] = 21.29, ["y"] = 79.11, },
					["36"] = { ["x"] = 10.58, ["y"] = 13.87, },
					["13"] = { ["x"] = 46.56, ["y"] = 67.97, },
					["947"] = { ["x"] = 86.41, ["y"] = 61.29, },
					},
				},
			["Elder Lunaro"] = {
				quest = { 13025 },
				["1"] = {
					["location"] = "Ruins of Tethys",
					["116"] = { ["x"] = 80.53, ["y"] = 37.11, },
					["113"] = { ["x"] = 81.99, ["y"] = 53.87, },
					["947"] = { ["x"] = 57.88, ["y"] = 16.28, },
					},
				},
			["Elder Meadowrun"] = {
				quest = { 8722 },
				["1"] = {
					["location"] = "The Weeping Cave",
					["tip"] = "Inside. Simple cave. Coordinates here are for the entrance.\nGo straight in, look right",
					["22"] = { ["x"] = 65.12, ["y"] = 38.73, },
					["23"] = { ["x"] = 2.38, ["y"] = 53.87, },
					["13"] = { ["x"] = 50.45, ["y"] = 32.85, },
					["947"] = { ["x"] = 88.50, ["y"] = 42.51, },
					},
				},
			["Elder Menkhaf"] = {
				quest = { 29742 },
				["1"] = {
					["location"] = "Khartut's Tomb",
					["tip"] = "On the eastern side, at the bottom of a ramp",
					["249"] = { ["x"] = 65.52, ["y"] = 18.68, },
					["71"] = { ["x"] = 21.55, ["y"] = 63.01, },
					["12"] = { ["x"] = 50.77, ["y"] = 86.04, },
					["947"] = { ["x"] = 18.99, ["y"] = 71.03, },
					},
				},
			["Elder Mistwalker"] = {
				quest = { 8685 },
				["1"] = {
					["location"] = "Dire Maul PvP area", ["tip"] = "Not inside the instance",
					["69"] = { ["x"] = 62.56, ["y"] = 31.08, },
					["199"] = { ["x"] = 3.54, ["y"] = 81.16, },
					["12"] = { ["x"] = 43.40, ["y"] = 65.69, },
					["947"] = { ["x"] = 15.51, ["y"] = 61.40, },
					},
				},
			["Elder Moonlance"] = {
				quest = { 29738 },
				["1"] = {
					["location"] = "Biel'aran Ridge",
					["tip"] = "A level 90 mob patrols here",
					["203"] = { ["x"] = 69.82, ["y"] = 82.51, },
					["205"] = { ["x"] = 57.26, ["y"] = 86.15, },
					["13"] = { ["x"] = 35.02, ["y"] = 68.94, },
					["947"] = { ["x"] = 80.24, ["y"] = 61.81, },
					},
				},
			["Elder Moonstrike"] = {
				quest = { 8714 },
				["1"] = {
					["location"] = "Above Scholomance",
					["tip"] = "No need to enter. Fly up. Located on the top",
					["22"] = { ["x"] = 69.18, ["y"] = 73.44, },
					["23"] = { ["x"] = 6.71, ["y"] = 90.89, },
					["25"] = { ["x"] = 90.66, ["y"] = 6.78, },
					["26"] = { ["x"] = 25.54, ["y"] = 8.00, },
					["13"] = { ["x"] = 50.88, ["y"] = 36.52, },
					["947"] = { ["x"] = 88.72, ["y"] = 44.47, },
					},
				},
			["Elder Moonwarden"] = {
				quest = { 8717 },
				["1"] = {
					["location"] = "Cross Roads",
					["tip"] = "Near the Wind Rider for Horde. Alliance players will need to drop\ndown. If hit run south (at the guard) "..
								"for an easier corpse rez.\nA spirit healer is conveniently nearby",
					["10"] = { ["x"] = 48.53, ["y"] = 59.27, },
					["7"] = { ["x"] = 87.90, ["y"] = 8.03, },
					["1"] = { ["x"] = 11.80, ["y"] = 64.36, },
					["199"] = { ["x"] = 53.19, ["y"] = 13.45, },
					["12"] = { ["x"] = 53.40, ["y"] = 52.05, },
					["947"] = { ["x"] = 20.24, ["y"] = 54.94, },
					},
				},
			["Elder Morningdew"] = {
				quest = { 8724 },
				["1"] = {
					["location"] = "Fizzle & Pozzik's Speedbarge",
					["64"] = { ["x"] = 77.09, ["y"] = 75.60, },
					["71"] = { ["x"] = 52.17, ["y"] = 8.60, },
					["12"] = { ["x"] = 56.77, ["y"] = 75.38, },
					["947"] = { ["x"] = 21.83, ["y"] = 65.98, },
					},
				},
			["Elder Morthie"] = {
				quest = { 13014 },
				["1"] = {
					["location"] = "Star's Rest", ["tip"] = "Western side. Good luck\nif Horde, you'll take hits",
					["115"] = { ["x"] = 29.75, ["y"] = 55.90, },
					["113"] = { ["x"] = 40.89, ["y"] = 60.07, },
					["947"] = { ["x"] = 47.72, ["y"] = 17.75, },
					},
				},
			["Elder Muraco"] = {
				quest = { 13032 },
				["1"] = {
					["location"] = "Camp Tunka'lo",
					["tip"] = "Southernmost end of the camp.\nVery safe for Alliance",
					["120"] = { ["x"] = 64.59, ["y"] = 51.34, },
					["113"] = { ["x"] = 67.43, ["y"] = 23.91, },
					["947"] = { ["x"] = 54.28, ["y"] = 9.20, },
					},
				},
			["Elder Nightwind"] = {
				quest = { 8723 },
				["1"] = {
					["location"] = "South of Bloodvenom Post",
					["tip"] = "He is standing in some ruins.  Winna's Kitten\nis nearby (a hunter favourite!)",
					["77"] = { ["x"] = 38.35, ["y"] = 52.85, },
					["62"] = { ["x"] = 54.82, ["y"] = 72.41, },
					["12"] = { ["x"] = 47.81, ["y"] = 29.38, },
					["947"] = { ["x"] = 17.59, ["y"] = 44.22, },
					},
				},
			["Elder Northal"] = {
				quest = { 13016 },
				["1"] = {
					["location"] = "Transitus Shield",
					["114"] = { ["x"] = 33.80, ["y"] = 34.36, },
					["113"] = { ["x"] = 14.62, ["y"] = 59.29, },
					["947"] = { ["x"] = 41.22, ["y"] = 17.56, },
					},
				},
			["Elder Obsidian"] = {
				quest = { 8645 },
				["1"] = {
					["location"] = "The Sepulcher", ["tip"] = "Alliance will need to drop in and be quick",
					["21"] = { ["x"] = 44.98, ["y"] = 41.14, },
					["25"] = { ["x"] = 5.95, ["y"] = 29.81, },
					["13"] = { ["x"] = 40.77, ["y"] = 39.27, },
					["947"] = { ["x"] = 83.32, ["y"] = 45.94, },
					},
				},
			["Elder Pamuya"] = {
				quest = { 13029 },
				["1"] = {
					["location"] = "Mightstone Quarry", ["tip"] = "North-east of Warsong Hold.\nAlliance should be safe here",
					["114"] = { ["x"] = 42.94, ["y"] = 49.57, },
					["113"] = { ["x"] = 17.58, ["y"] = 64.23, },
					["947"] = { ["x"] = 41.95, ["y"] = 18.73, },
					},
				},
			["Elder Primestone"] = {
				quest = { 8654 },
				["1"] = {
					["location"] = "The Crystal Vale",
					["81"] = { ["x"] = 30.80, ["y"] = 13.32, },
					["69"] = { ["x"] = 53.36, ["y"] = 83.45, },
					["12"] = { ["x"] = 41.67, ["y"] = 75.58, },
					["947"] = { ["x"] = 14.68, ["y"] = 66.08, },
					},
				},
			["Elder Ragetotem"] = {
				quest = { 8671 },
				["1"] = {
					["location"] = "Ruins of Uldum", 
					["tip"] = "At the entrance, not inside. This is the old Tanaris\nzone which has existed since before the Cataclysm",
					["71"] = { ["x"] = 37.24, ["y"] = 79.06, },
					["249"] = { ["x"] = 83.79, ["y"] = 37.37, },
					["12"] = { ["x"] = 53.85, ["y"] = 89.19, },
					["947"] = { ["x"] = 20.44, ["y"] = 72.52, },
					},
				},
			["Elder Riversong"] = {
				quest = { 8725 },
				["1"] = {
					["location"] = "Astranaar",
					["tip"] = "She is standing in a tall elven pagoda, at the north-west end of town.\nTough for low-level Horde as a "..
								"level 60 guard is adjacent. Run north\nand rez in the middle of the lake",
					["63"] = { ["x"] = 35.54, ["y"] = 48.91, },
					["65"] = { ["x"] = 72.06, ["y"] = 15.54, },
					["12"] = { ["x"] = 47.33, ["y"] = 38.79, },
					["947"] = { ["x"] = 17.36, ["y"] = 48.67, },
					},
				},
			["Elder Rumblerock"] = {
				quest = { 8636 },
				["1"] = {
					["location"] = "Dreadmaul Rock",
					["36"] = { ["x"] = 70.11, ["y"] = 45.39, },
					["13"] = { ["x"] = 51.17, ["y"] = 70.41, },
					["947"] = { ["x"] = 88.88, ["y"] = 62.60, },
					},
				},
			["Elder Runetotem"] = {
				quest = { 8670 },
				["1"] = {
					["location"] = "Razor Hill",
					["tip"] = "Adjacent to Burok the Flight Master. Alliance dive down on him. If you will die,\nrun due south at the "..
								"fence. A spirit healer is on the other side and you will be\nequidistant between guards for a quick "..
								"run south after rezzing",
					["1"] = { ["x"] = 53.22, ["y"] = 43.61, },
					["10"] = { ["x"] = 86.65, ["y"] = 40.18, },
					["12"] = { ["x"] = 59.36, ["y"] = 49.07, },
					["947"] = { ["x"] = 23.05, ["y"] = 53.53, },
					},
				},
			["Elder Sandrene"] = {
				quest = { 13018 },
				["1"] = {
					["location"] = "River's Heart", ["tip"] = "From the cluster of NPC's around\nthe Flight Master, go a little south",
					["119"] = { ["x"] = 49.78, ["y"] = 63.62, },
					["118"] = { ["x"] = 10.89, ["y"] = 95.36, },
					["113"] = { ["x"] = 25.11, ["y"] = 43.55, },
					["947"] = { ["x"] = 43.81, ["y"] = 13.84, },
					},
				},
			["Elder Sardis"] = {
				quest = { 13012 },
				["1"] = {
					["location"] = "Valliance Keep", ["tip"] = "Outside the wall to the north-east.\nHorde should be safe here",
					["114"] = { ["x"] = 59.09, ["y"] = 65.63, },
					["113"] = { ["x"] = 22.83, ["y"] = 69.44, },
					["947"] = { ["x"] = 43.25, ["y"] = 19.96, },
					},
				},
			["Elder Sekhemi"] = {
				quest = { 29741 },
				["1"] = {
					["location"] = "Ruins of Ammon", ["tip"] = "A level 90 mob pats nearby",
					["249"] = { ["x"] = 31.59, ["y"] = 62.98, },
					["327"] = { ["x"] = 84.11, ["y"] = 96.17, },
					["12"] = { ["x"] = 45.06, ["y"] = 93.50, },
					["947"] = { ["x"] = 16.29, ["y"] = 74.55, },
					},
				},
			["Elder Silvervein"] = {
				quest = { 8642 },
				["1"] = {
					["location"] = "Thelsamar",
					["48"] = { ["x"] = 33.33, ["y"] = 46.55, },
					["13"] = { ["x"] = 51.75, ["y"] = 60.85, },
					["947"] = { ["x"] = 89.19, ["y"] = 57.48, },
					},
				},
			["Elder Skychaser"] = {
				quest = { 8675 },
				["1"] = {
					["location"] = "Sentinel Hill", ["tip"] = "Atop the tower. Horde need to swoop\nin quick. You'll take a shot or two",
					["52"] = { ["x"] = 56.64, ["y"] = 47.09, },
					["13"] = { ["x"] = 42.07, ["y"] = 79.84, },
					["947"] = { ["x"] = 84.01, ["y"] = 67.64, },
					},
				},
			["Elder Skygleam"] = {
				quest = { 8720 },
				["1"] = {
					["location"] = "Vesthra's Power Stone pagoda", ["tip"] = "Just to the east",
					["76"] = { ["x"] = 64.73, ["y"] = 79.34, },
					["12"] = { ["x"] = 65.24, ["y"] = 40.13, },
					["947"] = { ["x"] = 25.83, ["y"] = 49.30, },
					},
				},
			["Elder Skyseer"] = {
				quest = { 8682 },
				["1"] = {
					["location"] = "Freewind Post", ["tip"] = "Eastern side, well enough away from other NPCs",
					["64"] = { ["x"] = 46.34, ["y"] = 51.00, },
					["70"] = { ["x"] = 28.52, ["y"] = 97.98, },
					["12"] = { ["x"] = 53.09, ["y"] = 72.44, },
					["947"] = { ["x"] = 20.09, ["y"] = 64.59, },
					},
				},
			["Elder Skywarden"] = {
				quest = { 13031 },
				["1"] = {
					["location"] = "Agmar's Hammer", ["tip"] = "Overlooking town, to the south-west.\nSafe enough for Alliance",
					["115"] = { ["x"] = 35.10, ["y"] = 48.35, },
					["113"] = { ["x"] = 42.58, ["y"] = 57.68, },
					["947"] = { ["x"] = 48.13, ["y"] = 17.18, },
					},
				},
			["Elder Snowcrown"] = {
				quest = { 8650 },
				["1"] = {
					["location"] = "Light's Hope Chapel", ["tip"] = "To the south, against the wall",
					["23"] = { ["x"] = 75.73, ["y"] = 54.56, },
					["13"] = { ["x"] = 57.71, ["y"] = 32.92, },
					["947"] = { ["x"] = 92.38, ["y"] = 42.54, },
					},
				},
			["Elder Starglade"] = {
				quest = { 8716 },
				["1"] = {
					["location"] = "Zul'Gurub", ["tip"] = "At the entrance",
					["224"] = { ["x"] = 63.28, ["y"] = 22.65, },
					["50"] = { ["x"] = 71.04, ["y"] = 34.30, },
					["13"] = { ["x"] = 47.47, ["y"] = 85.20, },
					["947"] = { ["x"] = 20.09, ["y"] = 64.59, },
					},
				},
			["Elder Starweave"] = {
				quest = { 8721 },
				["1"] = {
					["location"] = "Lor'danel", ["tip"] = "Western edge of town",
					["62"] = { ["x"] = 49.53, ["y"] = 18.95, },
					["12"] = { ["x"] = 46.88, ["y"] = 19.98, },
					["947"] = { ["x"] = 17.15, ["y"] = 39.77, },
					},
				},
			["Elder Stonebeard"] = {
				quest = { 13020 },
				["1"] = {
					["location"] = "Bouldercrag's Refuge", ["tip"] = "Go inside",
					["120"] = { ["x"] = 30.53, ["y"] = 36.86, },
					["118"] = { ["x"] = 92.07, ["y"] = 23.36, },
					["113"] = { ["x"] = 53.78, ["y"] = 18.11, },
					["947"] = { ["x"] = 50.90, ["y"] = 7.82, },
					},
				},
			["Elder Stonebrand"] = {
				quest = { 29735 },
				["1"] = {
					["location"] = "Temple of Earth (Deepholm)",
					["tip"] = "Take the Deepholm portal in your capital city.\nOn arrival, go to the exit. He is right there!",
					["207"] = { ["x"] = 49.70, ["y"] = 54.88, },
					["948"] = { ["x"] = 53.4, ["y"] = 23.3, },
					["947"] = { ["x"] = 47.6, ["y"] = 45.7, },
					},
				},
			["Elder Stonespire"] = {
				quest = { 8672 },
				["1"] = {
					["location"] = "Everlook", ["tip"] = "A tauren standing on a mound",
					["83"] = { ["x"] = 59.96, ["y"] = 49.94, },
					["12"] = { ["x"] = 59.09, ["y"] = 22.68, },
					["947"] = { ["x"] = 22.93, ["y"] = 41.05, },
					},
				},
			["Elder Stormbrow"] = {
				quest = { 8649 },
				["1"] = {
					["location"] = "Goldshire", ["tip"] = "Horde won't be troubled. Alliance may be\ntroubled by the RP in the inn",
					["37"] = { ["x"] = 39.79, ["y"] = 63.67, },
					["13"] = { ["x"] = 44.22, ["y"] = 75.84, },
					["947"] = { ["x"] = 85.16, ["y"] = 65.50, },
					},
				},
			["Elder Tauros"] = {
				quest = { 13027 },
				["1"] = {
					["location"] = "Zim'Torga", ["tip"] = "North-west edge of this circular camp",
					["121"] = { ["x"] = 58.91, ["y"] = 55.97, },
					["120"] = { ["x"] = 75.69, ["y"] = 92.64, },
					["113"] = { ["x"] = 71.88, ["y"] = 40.46, },
					["947"] = { ["x"] = 55.38, ["y"] = 13.11, },
					},
				},
			["Elder Thoim"] = {
				quest = { 13019 },
				["1"] = {
					["location"] = "Moa'ki Harbor", ["tip"] = "On the sea turtle jetty",
					["115"] = { ["x"] = 48.77, ["y"] = 78.18, },
					["113"] = { ["x"] = 46.90, ["y"] = 67.11, },
					["947"] = { ["x"] = 49.20, ["y"] = 19.41, },
					},
				},
			["Elder Thunderhorn"] = {
				quest = { 8681 },
				["1"] = {
					["location"] = "The Slithering Scar", ["tip"] = "A level 61 pat is difficult to avoid",
					["78"] = { ["x"] = 50.37, ["y"] = 76.16, },
					["71"] = { ["x"] = 17.58, ["y"] = 43.14, },
					["12"] = { ["x"] = 49.99, ["y"] = 82.15, },
					["947"] = { ["x"] = 18.62, ["y"] = 69.19, },
					},
				},
			["Elder Wanikaya"] = {
				quest = { 13024 },
				["1"] = {
					["location"] = "Rainspeaker Rapids", ["tip"] = "Just west of Freya",
					["119"] = { ["x"] = 63.80, ["y"] = 49.02, },
					["118"] = { ["x"] = 20.63, ["y"] = 85.22, },
					["113"] = { ["x"] = 28.55, ["y"] = 39.96, },
					["947"] = { ["x"] = 44.66, ["y"] = 12.99, },
					},
				},
			["Elder Whurain"] = {
				quest = { 13030 },
				["1"] = {
					["location"] = "Camp Oneqwah", ["tip"] = "Be quick if Alliance or you'll get hit",
					["116"] = { ["x"] = 64.18, ["y"] = 46.98, },
					["113"] = { ["x"] = 77.16, ["y"] = 56.79, },
					["947"] = { ["x"] = 56.69, ["y"] = 16.97, },
					},
				},
			["Elder Windrun"] = {
				quest = { 8688 },
				["1"] = {
					["location"] = "Crown Guard Tower", ["tip"] = "Inside",
					["23"] = { ["x"] = 35.58, ["y"] = 68.82, },
					["22"] = { ["x"] = 96.24, ["y"] = 52.74, },
					["13"] = { ["x"] = 53.74, ["y"] = 34.33, },
					["947"] = { ["x"] = 90.25, ["y"] = 43.30, },
					},
				},
			["Elder Windsong"] = {
				quest = { 29739 },
				["1"] = {
					["location"] = "Sanctuary of Malorne",
					["198"] = { ["x"] = 26.69, ["y"] = 62.05, },
					["77"] = { ["x"] = 63.68, ["y"] = 69.24, },
					["63"] = { ["x"] = 65.25, ["y"] = 6.08, },
					["62"] = { ["x"] = 78.57, ["y"] = 87.78, },
					["12"] = { ["x"] = 51.98, ["y"] = 32.08, },
					["947"] = { ["x"] = 19.56, ["y"] = 45.50, },
					},
				},
			["Elder Winterhoof"] = {
				quest = { 8674 },
				["1"] = {
					["location"] = "Booty Bay", ["tip"] = "Above the Auction House and the Bank",
					["224"] = { ["x"] = 37.32, ["y"] = 79.20, },
					["210"] = { ["x"] = 39.96, ["y"] = 72.51, },
					["13"] = { ["x"] = 43.30, ["y"] = 94.30, },
					["947"] = { ["x"] = 84.67, ["y"] = 75.38, },
					},
				},
			["Elder Windtotem"] = {
				quest = { 8680 },
				["1"] = {
					["location"] = "Ratchet", ["tip"] = "Behind the main building, at Gazlowe's /\nthe Flight Master end of town",
					["10"] = { ["x"] = 68.36, ["y"] = 69.96, },
					["1"] = { ["x"] = 33.35, ["y"] = 75.98, },
					["199"] = { ["x"] = 68.56, ["y"] = 21.73, },
					["12"] = { ["x"] = 56.50, ["y"] = 53.72, },
					["947"] = { ["x"] = 21.70, ["y"] = 55.73, },
					},
				},
			},
		},
	love = {
		fool = {
			achievement = 1704,
			[ "Arathi Basin Blacksmith" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "Behind the building works but so too at the flag.\nIf you die don't worry as Love Fools may be shared",
					["93"] = { ["x"] = 50.4, ["y"] = 43.5, },
					},
				["2"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "You must queue for Arathi Basin\nto enter the Battleground",
					["14"] = { ["x"] = 40.41, ["y"] = 45.72, },
					["13"] = { ["x"] = 50.82, ["y"] = 45.59, },
					["947"] = { ["x"] = 88.69, ["y"] = 49.32, },
					},
				},
			[ "Wintergrasp (Anywhere)" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"I Pitied the Fool\"",
					["123"] = { ["x"] = 44, ["y"] = 40, },
					["113"] = { ["x"] = 35, ["y"] = 51.5, },
					["947"] = { ["x"] = 46, ["y"] = 16, },
					},
				},
			[ "Naxxramas (Anywhere)" ] = {
				index = 5,
				["1"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "Naxxramas is floating in the sky. Enter through\nits base. You must then enter any of the portals",
					["115"] = { ["x"] = 87.31, ["y"] = 50.96, },
					["113"] = { ["x"] = 59.08, ["y"] = 58.51, },
					["947"] = { ["x"] = 52.21, ["y"] = 17.38, },
					},
				["2"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "Spawn your Love Fool anywhere here.\nTarget, then /pity and done!",
					["166"] = { ["x"] = 55.3, ["y"] = 48.5, },
					},
				},
			[ "Gurubashi Arena Battle Ring" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "Your Love Fool must spawn inside the Battle Ring but YOU\nmay safely stand at the very edge of one of "..
								"the two ramps\n(ie. still in \"The Great Arena\") and NOT be flagged for PvP",
					["210"] = { ["x"] = 46.91, ["y"] = 27.66, },
					["50"] = { ["x"] = 36.25, ["y"] = 81.50, },
					["224"] = { ["x"] = 41.51, ["y"] = 52.19, },
					["13"] = { ["x"] = 43.97, ["y"] = 89.95, },
					["947"] = { ["x"] = 85.03, ["y"] = 73.05, },
					},
				["2"] = {
					["location"] = "\"I Pitied the Fool\"",
					["tip"] = "Your Love Fool must spawn inside the Battle Ring but YOU\nmay safely stand at the very edge of one of "..
								"the two ramps\n(ie. still in \"The Great Arena\") and NOT be flagged for PvP",
					["210"] = { ["x"] = 47.58, ["y"] = 25.76, },
					},
				},
			[ "The Culling of Stratholme" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"I Pitied the Fool\"", ["tip"] = "Enter here. Fly down, deep inside",
					["71"] = { ["x"] = 64.77, ["y"] = 49.99, },
					["12"] = { ["x"] = 59.24, ["y"] = 83.49, },
					["947"] = { ["x"] = 23.00, ["y"] = 69.82, },
					},
				["2"] = {
					["location"] = "\"I Pitied the Fool\"", ["tip"] = "Fly down to here or grab a lift off the friendly Steward!",
					["74"] = { ["x"] = 32, ["y"] = 74, },
					},
				["3"] = {
					["location"] = "\"I Pitied the Fool\"", ["tip"] = "Just inside the entrance is fine",
					["75"] = { ["x"] = 55.5, ["y"] = 80.9, },
					},
				["4"] = {
					["location"] = "\"I Pitied the Fool\"", ["tip"] = "Spawn your Love Fool anywhere here.\nTarget, then /pity and done!",
					["130"] = { ["x"] = 87.9, ["y"] = 70.6, },
					},
				["5"] = {
					["location"] = "\"I Pitied the Fool\"", ["tip"] = "Take Zidormi's portal to The Caverns of Time. Enter\nthe Violet "..
									"Citadel, go up the stairs and turn left",
					["125"] = { ["x"] = 25.57, ["y"] = 51.35, },
					["127"] = { ["x"] = 22.16, ["y"] = 39.65, },
					["120"] = { ["x"] = 14.08, ["y"] = 93.12, },
					["118"] = { ["x"] = 73.41, ["y"] = 87.16, },
					["113"] = { ["x"] = 47.19, ["y"] = 40.65, },
					["947"] = { ["x"] = 49.27, ["y"] = 13.15, },
					},
				},
			},
		stinksA = {
			faction = "Alliance",
			[ "Inspector Snip Snagglebolt" ] = {
				quest = { 24655, 24656, 24848, 24657, 44558 },
				["1"] = {
					["location"] = "\"Dangerous Love\"",
					["tip"] = "Begins here and ends with a daily, \"Crushing the Crown\"\nsending you to Pyrewood Village, south of "..
								"Shadowfang\nKeep in Silverpine Forest",
					["84"] = { ["x"] = 61.51, ["y"] = 75.30, },
					["37"] = { ["x"] = 25.39, ["y"] = 40.11, },
					["13"] = { ["x"] = 43.00, ["y"] = 73.83, },
					["947"] = { ["x"] = 84.51, ["y"] = 64.43, },
					},
				["2"] = {
					["location"] = "\"Dangerous Love\"",
					["tip"] = "\"Crushing the Crown\" in Pyrewood Village, just south of\nShadowfang Keep in Silverpine Forest. You "..
								"must have\ncomleted the main quests in Stormwind. While here,\npickup the \"Follow the Recipe\" daily at (45.25,73.85)",
					["21"] = { ["x"] = 45.99, ["y"] = 72.67, },
					["25"] = { ["x"] = 6.82, ["y"] = 57.05, },
					["13"] = { ["x"] = 40.88, ["y"] = 42.52, },
					["947"] = { ["x"] = 83.37, ["y"] = 47.68, },
					},
				},
			},
		stinksH = {
			faction = "Horde",
			[ "Detective Snap Snagglebolt" ] = {
				quest = { 24536, 24541, 24850, 24576, 44546 },
				["1"] = {
					["location"] = "\"Dangerous Love\"",
					["tip"] = "Begins here and ends with a daily, \"Crushing the Crown\"\nsending you to Pyrewood Village, south of "..
								"Shadowfang\nKeep in Silverpine Forest",
					["85"] = { ["x"] = 50.80, ["y"] = 75.23, },
					["1"] = { ["x"] = 45.91, ["y"] = 5.50, },
					["10"] = { ["x"] = 79.92, ["y"] = 5.12, },
					["1"] = { ["x"] = 45.91, ["y"] = 5.50, },
					["12"] = { ["x"] = 58.31, ["y"] = 43.59, },
					["947"] = { ["x"] = 22.55, ["y"] = 50.94, },
					},
				["2"] = {
					["location"] = "\"Dangerous Love\"",
					["tip"] = "\"Crushing the Crown\" in Pyrewood Village, just south of\nShadowfang Keep in Silverpine Forest. you "..
								"must have\ncomleted the main quests in Orgrimmar. While here,\npickup the \"Follow the Recipe\" daily",
					["21"] = { ["x"] = 45.99, ["y"] = 72.67, },
					["25"] = { ["x"] = 6.82, ["y"] = 57.05, },
					["13"] = { ["x"] = 40.88, ["y"] = 42.52, },
					["947"] = { ["x"] = 83.37, ["y"] = 47.68, },
					},
				},
			},
		nationA = {
			achievement = 1697,
			faction = "Alliance",
			[ "The High Priestess" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Pickup from Kwee Q. Peddlefeet in Darnassus. Don't\nforget to obtain your Lovely Charm "..
								"Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["89"] = { ["x"] = 45.42, ["y"] = 57.77, },
					["57"] = { ["x"] = 29.74, ["y"] = 50.47, },
					["12"] = { ["x"] = 39.62, ["y"] = 9.94, },
					["947"] = { ["x"] = 13.71, ["y"] = 35.02, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to The Night Warrior",
					["89"] = { ["x"] = 43.01, ["y"] = 78.07, },
					["57"] = { ["x"] = 29.11, ["y"] = 55.79, },
					},
				},
			[ "The Prophet Velen" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Pickup from Kwee Q. Peddlefeet OUTSIDE The Exodar.\nDon't forget to obtain your Lovely Charm "..
								"Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["103"] = { ["x"] = 73.64, ["y"] = 57.00, },
					["97"] = { ["x"] = 33.03, ["y"] = 44.86, },
					["12"] = { ["x"] = 30.74, ["y"] = 26.10, },
					["947"] = { ["x"] = 9.51, ["y"] = 42.67, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to the Prophet Velen",
					["97"] = { ["x"] = 22.44, ["y"] = 44.20, },
					["103"] = { ["x"] = 32.86, ["y"] = 54.49, },
					},
				},
			[ "Lord of Ironforge" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Pickup from Kwee Q. Peddlefeet in The Commons.\nDon't forget to obtain your Lovely Charm "..
								"Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["87"] = { ["x"] = 33.57, ["y"] = 65.62, },
					["37"] = { ["x"] = 63.63, ["y"] = 29.83, },
					["13"] = { ["x"] = 47.01, ["y"] = 59.27, },
					["947"] = { ["x"] = 86.65, ["y"] = 56.64, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Enter here for the hand-in",
					["87"] = { ["x"] = 44.77, ["y"] = 49.17, },
					},
				["3"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to Muradin",
					["87"] = { ["x"] = 39.17, ["y"] = 56.09, },
					},
				},
			[ "King of Stormwind" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Pickup from Kwee Q. Peddlefeet in the Trade District.\nDon't forget to obtain your Lovely Charm "..
								"Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["84"] = { ["x"] = 62.54, ["y"] = 74.96, },
					["37"] = { ["x"] = 25.90, ["y"] = 39.94, },
					["13"] = { ["x"] = 43.04, ["y"] = 73.81, },
					["947"] = { ["x"] = 84.53, ["y"] = 64.42, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here",
					["84"] = { ["x"] = 87.04, ["y"] = 36.51, },
					["37"] = { ["x"] = 38.17, ["y"] = 20.70, },
					},
				},
			},
		nationH = {
			achievement = 1698,
			faction = "Horde",
			[ "High Overlord Saurfang" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Kwee Q. Peddlefeet is located in The Valley of Strength.\nDon't forget to obtain your Lovely Charm "..
								"Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["85"] = { ["x"] = 53.00, ["y"] = 76.82, },
					["1"] = { ["x"] = 46.63, ["y"] = 6.03, },
					["10"] = { ["x"] = 80.59, ["y"] = 5.60, },
					["12"] = { ["x"] = 58.41, ["y"] = 43.67, },
					["947"] = { ["x"] = 22.60, ["y"] = 50.98, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to Varok Saurfang, High\nOverlord and younger "..
									"brother to Broxigar",
					["85"] = { ["x"] = 48.53, ["y"] = 70.72, },
					},
				},
			[ "Quel'Thalas Regent Lord" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Kwee Q. Peddlefeet is located in The Bazaar. Don't\nforget to obtain your Lovely Charm Collectors Kit.\n"..
								"(The adjacent NPC offers a quick and easy daily)",
					["110"] = { ["x"] = 64.42, ["y"] = 66.53, },
					["94"] = { ["x"] = 54.69, ["y"] = 43.39, },
					["13"] = { ["x"] = 56.34, ["y"] = 14.58, },
					["947"] = { ["x"] = 91.64, ["y"] = 32.73, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to Lor'themar Theron",
					["110"] = { ["x"] = 53.79, ["y"] = 20.24, },
					["94"] = { ["x"] = 52.08, ["y"] = 32.02, },
					},
				},
			[ "High Chieftain Bloodhoof" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "Kwee Q. Peddlefeet is located at the base of the\nWind Rider Master on the central mesa. Don't\nforget "..
								"to obtain your Lovely Charm Collectors Kit.\n(The adjacent NPC offers a quick and easy daily)",
					["88"] = { ["x"] = 44.02, ["y"] = 52.60, },
					["7"] = { ["x"] = 39.39, ["y"] = 28.82, },
					["66"] = { ["x"] = 92.89, ["y"] = 55.64, },
					["199"] = { ["x"] = 17.52, ["y"] = 28.74, },
					["10"] = { ["x"] = 2.52, ["y"] = 78.99, },
					["12"] = { ["x"] = 46.22, ["y"] = 55.13, },
					["947"] = { ["x"] = 16.84, ["y"] = 56.40, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to Baine",
					["88"] = { ["x"] = 60.30, ["y"] = 51.69, },
					},
				},
			[ "The Banshee Queen" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"Nation of Adoration\"", 
					["tip"] = "ABOVE Undercity in the Ruins of Lordaeron. Pickup from Kwee Q. Peddlefeet.\nTo turn-in, descend into the "..
								"city and follow the city map guide pins.\n(The adjacent NPC offers a quick and easy daily)",
					["90"] = { ["x"] = 66.54, ["y"] = 38.61, },
					["18"] = { ["x"] = 61.93, ["y"] = 73.25, },
					["22"] = { ["x"] = 4.23, ["y"] = 60.55, },
					["21"] = { ["x"] = 76.55, ["y"] = 1.28, },
					["13"] = { ["x"] = 44.03, ["y"] = 35.16, },
					["947"] = { ["x"] = 85.06, ["y"] = 43.74, },
					},
				["2"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Enter here at sewer level to reach the Banshee Queen",
					["90"] = { ["x"] = 52.92, ["y"] = 63.25, },
					},
				["3"] = {
					["location"] = "\"Nation of Adoration\"", ["tip"] = "Hand in here to the Dark Lady",
					["90"] = { ["x"] = 58.05, ["y"] = 91.79, },
					},
				},
			},
		},
	noble = {
		hard = {
			[ "Marshall's Stand" ] = {
				achievement = 2416,
				["1"] = {
					["location"] = "\"Hard Boiled\"",
					["tip"] = "Set your hearth here. Go back to your bunny area\nand become \"bunnyfied\". Hearth. Run to Golakka.\n"..
								"Do not mount. Do not take damage",
					["78"] = { ["x"] = 53, ["y"] = 63, },
					["71"] = { ["x"] = 18.93, ["y"] = 36.39, },
					["12"] = { ["x"] = 50.26, ["y"] = 80.83, },
					["947"] = { ["x"] = 18.75, ["y"] = 68.56, },
					},
				},
			[ "Golakka Hot Springs" ] = {
				achievement = 2416,
				["1"] = {
					["location"] = "\"Hard Boiled\"",
					["tip"] = "Stand anywhere in the Golakka sub-zone.\nStand near the water's edge and wait.\nPatrolling mobs will "..
								"be up to level 60",
					["78"] = { ["x"] = 33, ["y"] = 56, },
					["81"] = { ["x"] = 90.45, ["y"] = 54.50, },
					["71"] = { ["x"] = 8.67, ["y"] = 32.80, },
					["12"] = { ["x"] = 48.25, ["y"] = 80.12, },
					["947"] = { ["x"] = 17.79, ["y"] = 68.23, },
					},
				},
			},
		desert = {
			achievement = 2436,
			[ "Badlands" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"Desert Rose\"",
					["tip"] = "Anywhere in the zone",
					["15"] = { ["x"] = 31, ["y"] = 42, },
					["13"] = { ["x"] = 51.61, ["y"] = 65.89, },
					["947"] = { ["x"] = 89.11, ["y"] = 60.18, },
					},
				},
			[ "Silithus" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"Desert Rose\"",
					["tip"] = "Anywhere in the zone",
					["81"] = { ["x"] = 40, ["y"] = 55, },
					["12"] = { ["x"] = 42.68, ["y"] = 80.18, },
					["947"] = { ["x"] = 15.16, ["y"] = 68.25, },
					},
				},
			[ "Thousand Needles" ] = {
				index = 5,
				["1"] = {
					["location"] = "\"Desert Rose\"",
					["tip"] = "Anywhere in the zone",
					["64"] = { ["x"] = 65, ["y"] = 67, },
					["71"] = { ["x"] = 44.79, ["y"] = 3.35, },
					["12"] = { ["x"] = 55.33, ["y"] = 74.35, },
					["947"] = { ["x"] = 21.14, ["y"] = 65.50, },
					},
				},
			[ "Desolace" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"Desert Rose\"",
					["tip"] = "Anywhere in the zone",
					["66"] = { ["x"] = 65, ["y"] = 64, },
					["7"] = { ["x"] = 16.39, ["y"] = 35.72, },
					["12"] = { ["x"] = 42.81, ["y"] = 56.15, },
					["947"] = { ["x"] = 15.23, ["y"] = 56.88, },
					},
				},
			[ "Tanaris" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"Desert Rose\"",
					["tip"] = "Anywhere in the zone",
					["71"] = { ["x"] = 51, ["y"] = 51, },
					["249"] = { ["x"] = 99.82, ["y"] = 4.69, },
					["12"] = { ["x"] = 56.54, ["y"] = 83.69, },
					["947"] = { ["x"] = 21.72, ["y"] = 69.91, },
					},
				},
			},
		flingA = {
			achievement = 2419,
			faction = "Alliance",
			[ "Azure Watch" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the camp",
					["97"] = { ["x"] = 48.46, ["y"] = 48.34, },
					["12"] = { ["x"] = 32.44, ["y"] = 26.49, },
					["947"] = { ["x"] = 10.32, ["y"] = 42.85, },
					},
				},
			[ "Goldshire" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the town",
					["37"] = { ["x"] = 41.12, ["y"] = 65.08, },
					["13"] = { ["x"] = 44.84, ["y"] = 74.92, },
					["947"] = { ["x"] = 85.5, ["y"] = 65, },
					},
				},
			[ "Dolanaar" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the town",
					["57"] = { ["x"] = 54.62, ["y"] = 53.23, },
					["12"] = { ["x"] = 42.9, ["y"] = 10.3, },
					["947"] = { ["x"] = 15.7, ["y"] = 34, },
					},
				},
			[ "Kharanos" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the town",
					["27"] = { ["x"] = 53.21, ["y"] = 52.13, },
					["13"] = { ["x"] = 45, ["y"] = 62, },
					["947"] = { ["x"] = 85.3, ["y"] = 58, },
					},
				},
			},
		flingH = {
			achievement = 2497,
			faction = "Horde",
			[ "Bloodhoof Village" ] = {
				index = 1,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the camp",
					["7"] = { ["x"] = 46.53, ["y"] = 58.77, },
					["199"] = { ["x"] = 22.77, ["y"] = 50.75, },
					["12"] = { ["x"] = 47.28, ["y"] = 59.56, },
					["947"] = { ["x"] = 17.37, ["y"] = 58.64, },
					},
				},
			[ "Falconwing Square" ] = {
				index = 3,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the Square",
					["94"] = { ["x"] = 47.14, ["y"] = 45.96, },
					["110"] = { ["x"] = 33.70, ["y"] = 76.99, },
					["13"] = { ["x"] = 55.43, ["y"] = 14.89, },
					["947"] = { ["x"] = 91.15, ["y"] = 32.90, },
					},
				},
			[ "Brill" ] = {
				index = 2,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the town",
					["18"] = { ["x"] = 60.81, ["y"] = 51.52, },
					["13"] = { ["x"] = 43.55, ["y"] = 33.30, },
					["947"] = { ["x"] = 84.80, ["y"] = 42.74, },
					},
				},
			[ "Razor Hill" ] = {
				index = 4,
				["1"] = {
					["location"] = "\"Spring Fling\"",
					["tip"] = "Anywhere in the encampment",
					["1"] = { ["x"] = 52.05, ["y"] = 43.44, },
					["12"] = { ["x"] = 58.99, ["y"] = 49.51, },
					["947"] = { ["x"] = 22.82, ["y"] = 53.85, },
					},
				},
			},
		},
	special = {
		timetravel = {
			[ "Zidormi" ] = {
				["1"] = {
					["location"] = "Darkshore", ["tip"] = "Zidormi allows you to visit Teldrassil\nbefore and after The Burning",
					["62"] = { ["x"] = 48.86, ["y"] = 24.46, },
					["12"] = { ["x"] = 46.76, ["y"] = 20.95, },
					["947"] = { ["x"] = 17.09, ["y"] = 40.23, },
					},
				["2"] = { 
					["location"] = "Dustwallow Marsh", 
					["tip"] = "Zidormi allows you to visit Theramore\nbefore and after the mana-bomb",
					["70"] = { ["x"] = 55.91, ["y"] = 49.54, },
					["199"] = { ["x"] = 71.05, ["y"] = 80.37, },
					["12"] = { ["x"] = 57.00, ["y"] = 65.53, },
					["947"] = { ["x"] = 21.94, ["y"] = 61.32, },
					},
				["3"] = {
					["location"] = "Silithus", ["tip"] = "Zidormi allows you to visit Silithus\nbefore and after Sargeras",
					["81"] = { ["x"] = 78.93, ["y"] = 21.97, },
					["78"] = { ["x"] = 20.36, ["y"] = 20.31, },
					["69"] = { ["x"] = 81.46, ["y"] = 88.51, },
					["12"] = { ["x"] = 46.97, ["y"] = 76.54, },
					["947"] = { ["x"] = 17.19, ["y"] = 66.53, },
					},
				["4"] = {
					["location"] = "Blasted Lands", 
					["tip"] = "Zidormi allows you to visit the Blasted Lands\nbefore and after the most recent invasion",
					["17"] = { ["x"] = 48.16, ["y"] = 7.28, },
					["51"] = { ["x"] = 34.94, ["y"] = 73.27, },
					["42"] = { ["x"] = 84.97, ["y"] = 53.67, },
					["13"] = { ["x"] = 51.86, ["y"] = 80.80, },
					["947"] = { ["x"] = 89.25, ["y"] = 68.16, },
					},
				["5"] = {
					["location"] = "Tirisfal Glades",
					["tip"] = "Zidormi allows you to visit the Undercity\nbefore and after Anduin's attack",
					["18"] = { ["x"] = 69.46, ["y"] = 62.80, },
					["22"] = { ["x"] = 12.14, ["y"] = 49.57, },
					["13"] = { ["x"] = 44.86, ["y"] = 34.00, },
					["947"] = { ["x"] = 85.50, ["y"] = 43.12, },
					},
				},
			[ "Rhonormu" ] = {
				["1"] = {
					["location"] = "The Scarab Dais", ["tip"] = "Rhonormu allows you to visit Silithus\nbefore and after Sargeras",
					["81"] = { ["x"] = 33.34, ["y"] = 80.70, },
					["249"] = { ["x"] = 13.10, ["y"] = 0.67, },
					["327"] = { ["x"] = 55.84, ["y"] = 0.87, },
					["12"] = { ["x"] = 41.95, ["y"] = 83.01, },
					["947"] = { ["x"] = 14.82, ["y"] = 69.59, },
					},
				},
			},
		},
	}		

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Data Preparation
--		================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local eventData, npcData, zoneData = {}, {}, {}

local function SetupLocalDataTables()

	local playerFaction = UnitFactionGroup( "player" )
	local index, zone;

	for k,v in pairs( tips ) do							-- k = event
		eventData[ k ] = {}
		for m,w in pairs( v ) do						-- m = sub-category
			eventData[ k ][ m ] = "y"
			for n,x in pairs( w ) do					-- n = name (or faction/achievement)
				if w.faction and ( w.faction ~= playerFaction ) then break end
				if ( n == "achievement" ) or ( n == "faction" ) then
				else
					for p,y in pairs( x ) do			-- p = indexStr (or faction/achievement/index/quest)
						if x.faction and ( x.faction ~= playerFaction ) then break end
						index = tonumber( p )
						if index then
							for q,z in pairs( y ) do	-- q = zoneStr (or location/tip )
								zone = tonumber( q )
								if zone then
									if not zoneData[ q ] then
										zoneData[ q ] = {}
									end
									if not zoneData[ q ][ k ] then
										zoneData[ q ][ k ] = {}
									end
									if not zoneData[ q ][ k ][ m ] then
										zoneData[ q ][ k ][ m ] = {}
									end
									-- zones[ zoneStr ][ event ][ sub-category ][ indexStr ]
									iStr = tostring( zoneData[ q ][ k ][ m ].next or "1" )
									zoneData[ q ][ k ][ m ][ iStr ] = {}
									zoneData[ q ][ k ][ m ][ iStr ].name = n
									zoneData[ q ][ k ][ m ][ iStr ].x = z.x
									zoneData[ q ][ k ][ m ][ iStr ].y = z.y
									zoneData[ q ][ k ][ m ][ iStr ].location = y.location
									zoneData[ q ][ k ][ m ][ iStr ].tip = y.tip
									zoneData[ q ][ k ][ m ].next = tonumber( iStr ) + 1
									
									zoneData[ q ][ k ][ m ][ iStr ].achievement = w.achievement or x.achievement or nil
									zoneData[ q ][ k ][ m ][ iStr ].index = x.index or nil
								end
							end
						elseif ( p == "quest" ) then
							for q,z in pairs( y ) do
								if not npcData[ n ] then
									npcData[ n ] = {}
								end
								if not npcData[ n ].quest then
									npcData[ n ].quest = {}
									npcData[ n ].quest[ 1 ] = z
								else
									npcData[ n ].quest[ #npcData[ n ].quest + 1 ] = z
								end					
							end
						end
					end
				end
			end
		end
	end

	for q,z in pairs( zoneData ) do							-- q = zoneStr
		for k,v in pairs( z ) do							-- k = event
			for m,w in pairs( v ) do						-- m = sub-category
				if w.next then
					zoneData[ q ][ k ][ m ].next = nil
				end
			end
		end
	end
	
	for m,w in pairs( eventData.lunar ) do
		eventData.lunar[ m ] = LongStrangeTripDB.showLunar
	end
	for m,w in pairs( eventData.love ) do
		eventData.love[ m ] = LongStrangeTripDB.showLove
	end
	for m,w in pairs( eventData.noble ) do
		eventData.noble[ m ] = LongStrangeTripDB.showNoble
	end
	eventData.special.timetravel = LongStrangeTripDB.showZidormi
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		World Map Setup
--		===============
--
--------------------------------------------------------------------------------------------------------------------------------------------

local worldMap = { width = 0, height = 0, firstTimeShowing = true, wasInCorrectZone = nil, mapIDStr = "",  }

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		World Map Tooltips
--		==================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local function WorldMapTooltipOnEnter( self )


	WorldMapTooltip:SetOwner( self, "ANCHOR_CURSOR" )

	if ( self.k == "lunar" ) then
		WorldMapTooltip:SetText( pc_colour_Prefix.. "Lunar Festival" )
	elseif ( self.k == "love" ) then
		WorldMapTooltip:SetText( pc_colour_Prefix.. "Love is in the Air" )
	elseif ( self.k == "noble" ) then
		WorldMapTooltip:SetText( pc_colour_Prefix.. "Noble Garden" )
	elseif ( self.k == "special" ) then
		if ( self.m == "timetravel" ) then
			WorldMapTooltip:SetText( pc_colour_Prefix.. "Zone Time Travel" )
		end
	end
	if zoneData[ self.q ][ self.k ][ self.m ][ self.n ].location then
		WorldMapTooltip:AddDoubleLine( pc_colour_Highlight.. zoneData[ self.q ][ self.k ][ self.m ][ self.n ].name,
										pc_colour_Highlight.. zoneData[ self.q ][ self.k ][ self.m ][ self.n ].location )
	else
		WorldMapTooltip:AddLine( pc_colour_Highlight.. zoneData[ self.q ][ self.k ][ self.m ][ self.n ].name )
	end
	if zoneData[ self.q ][ self.k ][ self.m ][ self.n ].tip then
		WorldMapTooltip:AddLine( pc_colour_PlainText.. zoneData[ self.q ][ self.k ][ self.m ][ self.n ].tip )
	end
	
	local achieveData, completed = false, false

	if zoneData[ self.q ][ self.k ][ self.m ][ self.n ].index then
		achieveData = true
		_, _, completed = GetAchievementCriteriaInfo( zoneData[ self.q ][ self.k ][ self.m ][ self.n ].achievement,
															zoneData[ self.q ][ self.k ][ self.m ][ self.n ].index)
	elseif zoneData[ self.q ][ self.k ][ self.m ][ self.n ].achievement then
		achieveData = true
		_, _, _, _, _, _, _, _, _, _, _, _, completed = GetAchievementInfo( zoneData[ self.q ][ self.k ][ self.m ][ self.n ].achievement )
	else
		if npcData[ zoneData[ self.q ][ self.k ][ self.m ][ self.n ].name ] then
			if npcData[ zoneData[ self.q ][ self.k ][ self.m ][ self.n ].name ].quest then
				completed = true
				for i,v in ipairs( npcData[ zoneData[ self.q ][ self.k ][ self.m ][ self.n ].name ].quest ) do
					achieveData = true
					if not IsQuestFlaggedCompleted( v ) then
						completed = false
					end
				end
			end
		end
	end
	
	if ( achieveData == true ) then
		WorldMapTooltip:AddDoubleLine( ( LongStrangeTripDB.showCoordinates == "y" )
												and "(".. format( "%.02f", zoneData[ self.q ][ self.k ][ self.m ][ self.n ].x ).. ",".. 
														format( "%.02f", zoneData[ self.q ][ self.k ][ self.m ][ self.n ].y ).. ")"
												or " ",
										( completed == true ) 
												and "\124cFF00FF00".. CRITERIA_COMPLETED
												or "\124cFFFF0000".. CRITERIA_NOT_COMPLETED )
	else
		if ( LongStrangeTripDB.showCoordinates == "y" ) then
			WorldMapTooltip:AddLine( "(".. format( "%.02f", zoneData[ self.q ][ self.k ][ self.m ][ self.n ].x ).. ",".. 
											format( "%.02f", zoneData[ self.q ][ self.k ][ self.m ][ self.n ].y ).. ")" )
		end
	end
	
	WorldMapTooltip:Show()
end

local function WorldMapTooltipOnLeave( self )
	WorldMapTooltip:Hide()
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Assign Pins to the World Map
--		============================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local function AssignWorldMapPins()

	local function CreateWorldMapPin( q, k, m, n )
		local pin = CreateFrame( "Button", "LST"..q..k.."-"..m..n, WorldMapFrame.ScrollContainer.Child, UIDropDownMenuTemplate )
		pin.q, pin.k, pin.m, pin.n = q, k, m, n
		pin:HookScript( "OnEnter", WorldMapTooltipOnEnter )
		pin:HookScript( "OnLeave", WorldMapTooltipOnLeave )
		local pinTexture = pin:CreateTexture( nil, "OVERLAY" )
		pin.t = texturesAssigned[ k ][ m ] and texturesAssigned[ k ][ m ] or texturesAssigned[ k ]
		pinTexture:SetTexture( textures[ pin.t ] )
		pin.pinTexture = pinTexture
		pin:SetFrameStrata( "HIGH" )
		pin:Hide()
		return pin
	end

	worldMap.width = WorldMapFrame.ScrollContainer.Child:GetWidth()
	worldMap.height = WorldMapFrame.ScrollContainer.Child:GetHeight()

	for q,z in pairs( zoneData ) do										-- q = zoneStr
		worldMap[ q ] = {}
		for k,v in pairs( z ) do										-- k = event
			worldMap[ q ][ k ] = {}
			for m,w in pairs( v ) do									-- m = sub-category
				worldMap[ q ][ k ][ m ] = {}
				for n,x in pairs( w ) do								-- n = iStr
					worldMap[ q ][ k ][ m ][ n ] = CreateWorldMapPin( q, k, m, n )
				end
			end
		end
	end

	worldMap.firstTimeShowing = false
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		Show on the World Map
--		=====================
--
--------------------------------------------------------------------------------------------------------------------------------------------

-- Quest / task completion is not checked with events and as such some changes from "not completed" to "completed" will slip through but
-- the code here catches most situations

local function AdjustWorldMapCoordinates( x, y )
	return ( x - 50 ) * worldMap.width / 100, ( worldMap.height / 2 ) - ( worldMap.height * y / 100 )
end

local function ShowOnWorldMap()

	if not WorldMapFrame:IsShown() then
		worldMap.forceUpdate = true 	-- Because I don't trap events
		return
	end	
	
	if ( worldMap.firstTimeShowing == true ) then 
		SetupLocalDataTables()
		AssignWorldMapPins()
	end
	
	worldMap.mapIDStr = tostring( WorldMapFrame:GetMapID() or 0 )
	
	-- Hide decisions
	
	if not zoneData[ worldMap.mapIDStr ] then
		if worldMap.wasInCorrectZone then
			for k,v in pairs( worldMap[ worldMap.mapOldIDStr ] ) do
				for m,w in pairs( v ) do
					if w[ "1" ]:IsVisible() or ( LongStrangeTripDB.showCompletedQuests == "n" ) then
						for n,z in pairs( w ) do
							z:Hide()
						end
					end
				end
			end
			worldMap.wasInCorrectZone = nil
		end
		worldMap.fullScreenOld = nil
		return
	end
	
	local fullScreen = tostring( GetCVar( "miniWorldMap" ) )

	if worldMap.wasInCorrectZone then
		if ( worldMap.mapIDStr ~= worldMap.mapOldIDStr ) or not worldMap.fullScreenOld 
						or ( worldMap.fullScreenOld ~= fullScreen ) then
			for k,v in pairs( worldMap[ worldMap.mapOldIDStr ] ) do
				for m,w in pairs( v ) do
					if w[ "1" ]:IsVisible() or ( LongStrangeTripDB.showCompletedQuests == "n" ) then
						for n,z in pairs( w ) do
							z:Hide()
						end
					end
				end
			end
		end
	end
	
	worldMap.wasInCorrectZone = true

	if not worldMap.forceUpdate then
		if ( worldMap.mapIDStr == worldMap.mapOldIDStr ) and ( fullScreen == worldMap.fullScreenOld ) then
			return
		end
	end
	worldMap.forceUpdate = nil

	-- Show and sizing decisions
	
	worldMap.mapOldIDStr = worldMap.mapIDStr
	worldMap.fullScreenOld = fullScreen
	worldMap.width = WorldMapFrame.ScrollContainer.Child:GetWidth()
	worldMap.height = WorldMapFrame.ScrollContainer.Child:GetHeight()
	local questData, completed = false, false

	for k,v in pairs( worldMap[ worldMap.mapIDStr ] ) do
		for m,w in pairs( v ) do
			if ( eventData[ k ][ m ] == "y" ) then
				if ( LongStrangeTripDB.showCompletedQuests == "n" ) then
					for n,z in pairs( w ) do
						achieveData, completed = false, false
						if zoneData[ z.q ][ z.k ][ z.m ][ z.n ].index then
							achieveData = true
							_, _, completed = GetAchievementCriteriaInfo( zoneData[ z.q ][ z.k ][ z.m ][ z.n ].achievement,
																			zoneData[ z.q ][ z.k ][ z.m ][ z.n ].index)
						elseif zoneData[ z.q ][ z.k ][ z.m ][ z.n ].achievement then
							achieveData = true
							_, _, _, _, _, _, _, _, _, _, _, _, completed = 
																	GetAchievementInfo( zoneData[ z.q ][ z.k ][ z.m ][ z.n ].achievement )
						else
							if npcData[ zoneData[ z.q ][ z.k ][ z.m ][ z.n ].name ] then
								if npcData[ zoneData[ z.q ][ z.k ][ z.m ][ z.n ].name ].quest then
									for i,v in ipairs( npcData[ zoneData[ z.q ][ z.k ][ z.m ][ z.n ].name ].quest ) do
										achieveData = true
										if IsQuestFlaggedCompleted( v ) then
											completed = true
										else
											completed = false
										end
									end
								end
							end
						end
						if ( achieveData == false ) or ( completed == false ) then
							if not z:IsVisible() then
								local size = LongStrangeTripDB.pinSize * textures.size[ z.t ] * scaling[ fullScreen ][ z.q ]
								z.pinTexture:SetSize( size, size )
								z:SetSize( size, size )						
								local x, y = AdjustWorldMapCoordinates( zoneData[ z.q ][ z.k ][ z.m ][ z.n ].x, 
																		zoneData[ z.q ][ z.k ][ z.m ][ z.n ].y )
								z.pinTexture:ClearAllPoints()
								z.pinTexture:SetPoint( "CENTER", WorldMapFrame.ScrollContainer.Child, "CENTER", x, y )
								z:ClearAllPoints()
								z:SetPoint( "CENTER", WorldMapFrame.ScrollContainer.Child, "CENTER", x, y )
								z:Show()
							end
						else
							z:Hide()
						end
					end
				else
					for n,z in pairs( w ) do
						if not z:IsVisible() then
							local size = LongStrangeTripDB.pinSize * textures.size[ z.t ] * scaling[ fullScreen ][ z.q ]
							z.pinTexture:SetSize( size, size )
							z:SetSize( size, size )						
							local x, y = AdjustWorldMapCoordinates( zoneData[ z.q ][ z.k ][ z.m ][ z.n ].x, 
																	zoneData[ z.q ][ z.k ][ z.m ][ z.n ].y )
							z.pinTexture:ClearAllPoints()
							z.pinTexture:SetPoint( "CENTER", WorldMapFrame.ScrollContainer.Child, "CENTER", x, y )
							z:ClearAllPoints()
							z:SetPoint( "CENTER", WorldMapFrame.ScrollContainer.Child, "CENTER", x, y )
							z:Show()
						end
					end
				end
			else
				if w[ "1" ]:IsVisible() or ( LongStrangeTripDB.showCompletedQuests == "n" ) then
					for n,z in pairs( w ) do
						z:Hide()
					end
				end
			end
		end
	end
end

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		World Map's "Magnifying Glass" Drop Down Menu Options
--		=====================================================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local function ToggleLunarFestival()
	LongStrangeTripDB.showLunar = ( LongStrangeTripDB.showLunar == "y" ) and "n" or "y"
	for m,w in pairs( eventData.lunar ) do
		eventData.lunar[ m ] = LongStrangeTripDB.showLunar
	end
	worldMap.forceUpdate = true
end

local function ToggleLove()
	LongStrangeTripDB.showLove = ( LongStrangeTripDB.showLove == "y" ) and "n" or "y"
	for m,w in pairs( eventData.love ) do
		eventData.love[ m ] = LongStrangeTripDB.showLove
	end
	worldMap.forceUpdate = true
end

local function ToggleNoble()
	LongStrangeTripDB.showNoble = ( LongStrangeTripDB.showNoble == "y" ) and "n" or "y"
	for m,w in pairs( eventData.noble ) do
		eventData.noble[ m ] = LongStrangeTripDB.showNoble
	end
	worldMap.forceUpdate = true
end

local function ToggleZidormi()
	LongStrangeTripDB.showZidormi = ( LongStrangeTripDB.showZidormi == "y" ) and "n" or "y"
	eventData.special.timetravel = LongStrangeTripDB.showZidormi
	worldMap.forceUpdate = true
end

local function ToggleCompletedQuests()
	LongStrangeTripDB.showCompletedQuests = ( LongStrangeTripDB.showCompletedQuests == "y" ) and "n" or "y"
	worldMap.forceUpdate = true
end

local function ToggleCoordinates()
	LongStrangeTripDB.showCoordinates = ( LongStrangeTripDB.showCoordinates == "y" ) and "n" or "y"
end

local function AddMagnifyingGlassOptions()

	local info = UIDropDownMenu_CreateInfo()
	UIDropDownMenu_AddSeparator( 1 )
	info.isTitle = true
	info.text = "Long Strange Trip"
	info.notCheckable = true
	info.isNotRadio = true
	UIDropDownMenu_AddButton( info, 1 )
	info.isTitle = nil
	info.disabled = nil		
	info.text = "Lunar Festival"
	info.func = ToggleLunarFestival
	info.notCheckable = nil
	info.keepShownOnClick = true
	info.checked = LongStrangeTripDB.showLunar == "y"
	UIDropDownMenu_AddButton( info, 1 )	
	info.text = "Love is in the Air"
	info.func = ToggleLove
	info.checked = LongStrangeTripDB.showLove == "y"
	UIDropDownMenu_AddButton( info, 1 )	
	info.text = "Noble Garden"
	info.func = ToggleNoble
	info.checked = LongStrangeTripDB.showNoble == "y"
	UIDropDownMenu_AddButton( info, 1 )	
	info.text = "Zidormi"
	info.func = ToggleZidormi
	info.checked = LongStrangeTripDB.showZidormi == "y"
	UIDropDownMenu_AddButton( info, 1 )	
	info.text = "Completed Tasks"
	info.func = ToggleCompletedQuests
	info.checked = LongStrangeTripDB.showCompletedQuests == "y"
	UIDropDownMenu_AddButton( info, 1 )	
	info.text = "Show Coordinates"
	info.func = ToggleCoordinates
	info.checked = LongStrangeTripDB.showCoordinates == "y"
	UIDropDownMenu_AddButton( info, 1 )	
end
	
--------------------------------------------------------------------------------------------------------------------------------------------
--
--		OnEvent Handler
--		===============
--
--------------------------------------------------------------------------------------------------------------------------------------------

local eventFrame = CreateFrame( "Frame" )

local function OnEventHandler( self, event, arg1, ...)

	if event == "ADDON_LOADED" then
	
		if arg1 ~= addonName then return end
		
		if not LongStrangeTripDB then LongStrangeTripDB = {} end
		LongStrangeTripDB.pinSize = LongStrangeTripDB.pinSize or 25
		LongStrangeTripDB.showLunar = LongStrangeTripDB.showLunar or "y"
		LongStrangeTripDB.showLove = LongStrangeTripDB.showLove or "y"
		LongStrangeTripDB.showNoble = LongStrangeTripDB.showNoble or "y"
		LongStrangeTripDB.showZidormi = LongStrangeTripDB.showZidormi or "y"
		LongStrangeTripDB.showCompletedQuests = LongStrangeTripDB.showCompletedQuests or "y"
		LongStrangeTripDB.showCoordinates = LongStrangeTripDB.showCoordinates or "y"
		
		eventFrame:UnregisterEvent( "ADDON_LOADED" )
		
		addonTitle = GetAddOnMetadata( addonName, "Title" )
	
	elseif event == "PLAYER_ENTERING_WORLD" then
	
		for _, overlayFrame in next, WorldMapFrame.overlayFrames do
			if overlayFrame.Border and ( overlayFrame.Border:GetTexture() == "Interface\\Minimap\\MiniMap-TrackingBorder" )  then
				hooksecurefunc( overlayFrame, "InitializeDropDown", AddMagnifyingGlassOptions )
				break
			end
		end

		eventFrame:UnregisterEvent( "PLAYER_ENTERING_WORLD" )
	end
end

eventFrame:RegisterEvent( "ADDON_LOADED" )
eventFrame:RegisterEvent( "PLAYER_ENTERING_WORLD" )
eventFrame:SetScript( "OnEvent", OnEventHandler )

--------------------------------------------------------------------------------------------------------------------------------------------
--
--		OnUpdate Handler
--		================
--
--------------------------------------------------------------------------------------------------------------------------------------------

local timeSinceLastUpdate = 0

local function OnUpdateHandler()

	local curTime = GetTime()
	if curTime - timeSinceLastUpdate <= 0.05 then return end
	timeSinceLastUpdate = curTime

	ShowOnWorldMap()
end

eventFrame:SetScript( "OnUpdate", OnUpdateHandler )